@@ -1,4 +1,5 @@
 mod aliases;
+mod attack;
 mod class;
 mod race;
 mod results;
@@ -6,6 +7,7 @@ mod stats;
 mod status;
 
 pub use aliases::{Allies, Elements, Enemies, Items, Paths, Rooms};
+pub use attack::Attack;
 pub use class::Class;
 pub use race::Race;
 pub use results::{Action, CmdResult};
